@@ -36,9 +36,11 @@ class AttrDictX(Transform):
         members: Union[Dict[str, Any], List[Tuple[str, Any]]],
         name: str = "AttrDict",
     ) -> None:
-        super().__init__(name)
+        super().__init__(name, hint="AttrDict")
+
         self.members = dict(members)
         self.__nbytes__ = 0
+
         for transform in self.members.values():
             try:
                 self.__nbytes__ += transform.nbytes
