@@ -98,8 +98,10 @@ class BitField(property):
         if isinstance(self._argrepr, str):
             repr_format = self._argrepr
 
-        elif isinstance(self._typ, EnumMeta):
-            repr_format = f"{self.name}={{repr(self.{self.name}).split(':')[0][1:]}}"
+        elif isinstance(self._typ, (EnumMeta, EnumX)):
+            repr_format = (
+                f"{self.name}={{repr(self.{self.name}).split(':')[0].lstrip('<')}}"
+            )
 
         else:
             repr_format = f"{self.name}={{self.{self.name}!r}}"
