@@ -3,6 +3,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 """Pack/unpack bytes summary."""
 
+from enum import Enum
 from typing import Any, Generator, List, Tuple, Union
 
 
@@ -120,6 +121,9 @@ class Record(Base):
         # FUTURE - Any return really should be str but mypy complains
         #          leave this return self._value and leave application
         #          convert?
+        if isinstance(self._value, Enum):
+            return repr(self._value).split(":", 1)[0][1:]
+
         return str(self._value)
 
     @value.setter
