@@ -152,7 +152,9 @@ class Member(property):
             repr_format = self._argrepr
 
         elif isinstance(self._fmt, (EnumX, FlagX)):
-            repr_format = f"{self.name}={{repr(self.{self.name}).split(':', 1)[0][1:]}}"
+            repr_format = (
+                f"{self.name}={{repr(self.{self.name}).split(':', 1)[0].lstrip('<')}}"
+            )
 
         else:
             repr_format = f"{self.name}={{self.{self.name}!r}}"
