@@ -15,13 +15,13 @@ from .exceptions import (
     SizeError,
     UnpackError,
 )
-from .items import calcsize as _calcsize, items, Format
+from .items import calcsize as _calcsize, items, ItemsFormat
 from .transform import Transform
 
 getbytes.__module__ = "plum"
 
 
-def calcsize(fmt: Format) -> int:
+def calcsize(fmt: ItemsFormat) -> int:
     """Calculate format size (raise SizeError if variably sized)."""
     if isinstance(fmt, DataMeta):
         nbytes = getattr(fmt, "__nbytes__")
@@ -38,7 +38,7 @@ def calcsize(fmt: Format) -> int:
     return nbytes
 
 
-def pack(value: Any, fmt: Format = None) -> bytes:
+def pack(value: Any, fmt: ItemsFormat = None) -> bytes:
     """Pack value as formatted bytes.
 
     :raises: ``PackError`` if type error, value error, etc.
@@ -57,7 +57,7 @@ def pack(value: Any, fmt: Format = None) -> bytes:
     return b"".join(pieces)
 
 
-def pack_and_dump(value: Any, fmt: Format = None) -> Tuple[bytes, Dump]:
+def pack_and_dump(value: Any, fmt: ItemsFormat = None) -> Tuple[bytes, Dump]:
     """Pack value as formatted bytes and produce bytes summary.
 
     :raises: ``PackError`` if type error, value error, etc.
@@ -78,7 +78,7 @@ def pack_and_dump(value: Any, fmt: Format = None) -> Tuple[bytes, Dump]:
     return b"".join(pieces), dump
 
 
-def unpack(fmt: Format, buffer: bytes) -> Any:
+def unpack(fmt: ItemsFormat, buffer: bytes) -> Any:
     """Unpack value from formatted bytes.
 
     :raises: ``UnpackError`` if insufficient bytes or value error
@@ -97,7 +97,7 @@ def unpack(fmt: Format, buffer: bytes) -> Any:
     return value
 
 
-def unpack_and_dump(fmt: Format, buffer: bytes):
+def unpack_and_dump(fmt: ItemsFormat, buffer: bytes):
     """Unpack value from formatted bytes and produce a packed bytes summary.
 
     :raises: ``UnpackError`` if insufficient bytes or value error
