@@ -18,32 +18,23 @@ class TestAttrDictX:
 
     """Test AttrDictX features."""
 
-    def test_repr_default_name(self):
-        expected_repr = Baseline(
-            """
-            <transform 'AttrDict'>
-            """
-        )
+    def test_default_name(self):
+        xform = AttrDictX(dict(m1=uint8, m2=uint16))
+        assert xform.name == "AttrDict"
 
-        assert repr(AttrDictX(dict(m1=uint8, m2=uint16))) == expected_repr
+    def test_explicit_name(self):
+        xform = AttrDictX(dict(m1=uint8, m2=uint16), name="name")
+        assert xform.name == "name"
 
-    def test_repr_explicit_name(self):
-        expected_repr = Baseline(
-            """
-            <transform 'EmptyDict'>
-            """
-        )
-
-        assert (
-            repr(AttrDictX(dict(m1=uint8, m2=uint16), name="EmptyDict"))
-            == expected_repr
-        )
+    def test_default_hint(self):
+        xform = AttrDictX(dict(m1=uint8, m2=uint16))
+        assert xform.__hint__ == "AttrDict"
 
     def test_size_error(self):
         """Verify no size when a member has no size."""
         expected_message = Baseline(
             """
-            'AttrDict' transform sizes vary
+            <transform 'AttrDict'> sizes vary
             """
         )
 
