@@ -778,6 +778,36 @@ class TestTolerantEnum:
         bitfields.f2 = 3
         assert int(bitfields) == 3 << 2
 
+    def test_happy_dump(self):
+        expected_dump = Baseline(
+            """
+            +--------+--------+----------+----------+-----------------------------+
+            | Offset | Access | Value    | Bytes    | Format                      |
+            +--------+--------+----------+----------+-----------------------------+
+            | 0      |        | 4        | 04       | ForTolerantEnum (BitFields) |
+            |  [0:2] | f1     | 0        | ......00 | int                         |
+            |  [2:6] | f2     | MyEnum.A | ..0001.. | myenum                      |
+            |  [6:8] | f3     | 0        | 00...... | int                         |
+            +--------+--------+----------+----------+-----------------------------+
+            """
+        )
+        assert str(ForTolerantEnum.from_int(1 << 2).dump) == expected_dump
+
+    def test_tolerant_dump(self):
+        expected_dump = Baseline(
+            """
+            +--------+--------+-------+----------+-----------------------------+
+            | Offset | Access | Value | Bytes    | Format                      |
+            +--------+--------+-------+----------+-----------------------------+
+            | 0      |        | 0     | 00       | ForTolerantEnum (BitFields) |
+            |  [0:2] | f1     | 0     | ......00 | int                         |
+            |  [2:6] | f2     | 0     | ..0000.. | myenum                      |
+            |  [6:8] | f3     | 0     | 00...... | int                         |
+            +--------+--------+-------+----------+-----------------------------+
+            """
+        )
+        assert str(ForTolerantEnum.from_int(0).dump) == expected_dump
+
 
 class TestAsDict:
 
