@@ -10,6 +10,7 @@ from typing import Type
 from baseline import Baseline
 
 from plum.bitfields import BitFields, bitfield
+from plum.enum import EnumX
 
 from sample_bitfields import Register
 
@@ -70,7 +71,43 @@ class TestVanilla(Base):
         """
         def __repr__(self) -> str:
             try:
-                return f"{type(self).__name__}(m0={self.m0!r}, m1={repr(self.m1).split(':')[0][1:]})"
+                return f"{type(self).__name__}(m0={self.m0!r}, m1={repr(self.m1).split(':')[0].lstrip('<')})"
+            except Exception:
+                return f"{type(self).__name__}()"
+
+        """
+    )
+
+    def test_repr(self):
+        actual_repr = repr(self.sample)  # pylint: disable=no-member
+
+        assert actual_repr == self.repr_baseline  # pylint: disable=no-member
+
+
+class TestTolerantEnum(Base):
+
+    """Test structure representation with invalid enum member."""
+
+    class Sample(BitFields):
+
+        """Sample bit fields data store transform type."""
+
+        m0: int = bitfield(size=4)
+        m1: int = bitfield(size=4, typ=EnumX(enum=Register, strict=False))
+
+    sample = Sample(m0=0, m1=15)
+
+    repr_baseline = Baseline(
+        """
+        Sample(m0=0, m1=15)
+        """
+    )
+
+    implementation_baseline = Baseline(
+        """
+        def __repr__(self) -> str:
+            try:
+                return f"{type(self).__name__}(m0={self.m0!r}, m1={repr(self.m1).split(':')[0].lstrip('<')})"
             except Exception:
                 return f"{type(self).__name__}()"
 
