@@ -10,10 +10,13 @@ class TestDefault:
 
     """Test explicitly defined with positional argument."""
 
-    ipv4address = IPv4AddressX("ipv4address")
+    ipv4address = IPv4AddressX()
+
+    def test_hint(self):
+        assert self.ipv4address.__hint__ == "IPv4Address"
 
     def test_name(self):
-        assert self.ipv4address.name == "ipv4address"
+        assert self.ipv4address.name == "IPv4Address"
 
     def test_byteorder(self):
         assert self.ipv4address.byteorder == "big"
@@ -26,10 +29,13 @@ class TestPositional:
 
     """Test explicitly defined with positional argument."""
 
-    ipv4address = IPv4AddressX("ipv4address", "little")
+    ipv4address = IPv4AddressX("little", "name")
+
+    def test_hint(self):
+        assert self.ipv4address.__hint__ == "IPv4Address"
 
     def test_name(self):
-        assert self.ipv4address.name == "ipv4address"
+        assert self.ipv4address.name == "name"
 
     def test_byteorder(self):
         assert self.ipv4address.byteorder == "little"
@@ -42,4 +48,4 @@ class TestKeyword(TestPositional):
 
     """Test explicitly defined with keyword argument."""
 
-    ipv4address = IPv4AddressX(name="ipv4address", byteorder="little")
+    ipv4address = IPv4AddressX(byteorder="little", name="name")
