@@ -10,7 +10,7 @@ from plum.conformance import wrap_message
 from plum.exceptions import PackError
 from plum.none import NoneX
 
-nonex = NoneX("nonex")
+nonex = NoneX(name="nonex")
 
 
 class TestInvalidPackValue:
