@@ -5,6 +5,7 @@
 
 import doctest
 import os
+import sys
 
 import pytest
 
@@ -31,6 +32,8 @@ def get_docfiles():
                     continue  # do not test examples from 3rd-party packages
                 if filename in "about.rst":
                     continue  # contains examples of future functionality
+                if sys.version_info < (3, 11) and filename == "flag.rst":
+                    continue  # 3.11 reversed order of repr of or'd flags
                 docfiles.append(os.path.join(dirpath, filename))
     return docfiles
 
